@@ -151,6 +151,7 @@ OC.L10N.register(
     "_{duration} month_::_{duration} months_" : ["{duration} mes","{duration} meses"],
     "_{duration} year_::_{duration} years_" : ["{duration} añu","{duration} años"],
     "Update" : "Anovar",
+    "(copy)" : "(copia)",
     "Location" : "Llocalización",
     "Create a Talk room" : "Crear una sala de Talk",
     "Description" : "Descripción",
@@ -207,6 +208,7 @@ OC.L10N.register(
     "Accept" : "Aceptar",
     "Decline" : "Refugar",
     "Tentative" : "Provisional",
+    "Copied to clipboard" : "Copióse nel cartafueyu",
     "No attendees yet" : "Nun hai nengún asistente",
     "Attendees" : "Asistentes",
     "Remove group" : "Quitar el grupu",
@@ -242,12 +244,14 @@ OC.L10N.register(
     "Subscribe" : "Soscribise",
     "Time:" : "Hora:",
     "Personal" : "Personal",
+    "Discard changes" : "Escartar los cambeos",
     "Edit event" : "Editar eventu",
     "Event does not exist" : "L'eventu nun esiste",
     "All day" : "Tol día",
     "Invite" : "Convidar",
     "Untitled event" : "Eventu ensin títulu",
     "Close" : "Zarrar",
+    "This event was cancelled" : "Esti eventu anulóse",
     "Title" : "Títulu",
     "Participants" : "Participantes",
     "Submit" : "Unviar",
