@@ -56,7 +56,6 @@ OC.L10N.register(
     "second" : "drugi",
     "Other" : "Ostali",
     "Status" : "Status",
-    "can edit" : "mogu mijenjati",
-    "Keyboard shortcuts" : "Tipkovni prečaci"
+    "can edit" : "mogu mijenjati"
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
