@@ -16,10 +16,10 @@ OC.L10N.register(
     "Restore" : "Վերականգնել",
     "Delete permanently" : "Ջնջել ընդմիշտ",
     "Share link" : "Կիսվել հղմամբ",
-    "can edit" : "կարող է խմբագրել",
     "Share with users or groups" : "Կիսվել օգտատերերի կամ խմբերի հետ",
     "Save" : "Պահպանել",
     "Cancel" : "Չեղարկել",
+    "General" : "Ընդհանուր",
     "Update" : "Թարմացնել",
     "Location" : "Տեղակայություն",
     "Description" : "Նկարագրություն",
@@ -42,6 +42,8 @@ OC.L10N.register(
     "Repeat" : "Կրկնել",
     "never" : "երբեք",
     "after" : "հետո",
+    "Yes" : "Այո",
+    "No" : "Ոչ",
     "Global" : "Ընդհանուր",
     "Personal" : "Անձնական",
     "Edit event" : "Խմբագրել դեպքը",
@@ -50,6 +52,7 @@ OC.L10N.register(
     "Weekly" : "Շաբաթական",
     "second" : "երկրորդ",
     "Other" : "Այլ",
-    "Confirmed" : "Հաստատված"
+    "Confirmed" : "Հաստատված",
+    "can edit" : "կարող է խմբագրել"
 },
 "nplurals=2; plural=(n != 1);");
