@@ -22,7 +22,6 @@ OC.L10N.register(
     "Appointments" : "Afspraken",
     "Schedule appointment \"%s\"" : "Plan afspraak \"%s\"",
     "Schedule an appointment" : "Plan een afspraak",
-    "%1$s - %2$s" : "%1$s - %2$s",
     "Prepare for %s" : "Voorbereiden op %s",
     "Follow up for %s" : "Follow-up voor %s",
     "Your appointment \"%s\" with %s needs confirmation" : "Je afspraak \"%s\" met %s moet nog bevestigd worden",
@@ -64,6 +63,7 @@ OC.L10N.register(
     "Appointment link could not be copied to clipboard" : "Afspraaklink kon niet naar klembord gekopieerd worden",
     "Preview" : "Voorbeeld",
     "Copy link" : "Link kopiëren",
+    "Duplicate" : "Duplicaat",
     "Edit" : "Bewerk",
     "Delete" : "Verwijderen",
     "Appointment schedules" : "Afspraakschema's",
@@ -147,6 +147,7 @@ OC.L10N.register(
     "Unshare from me" : "Stop delen met mij",
     "Save" : "Opslaan",
     "No title" : "Geen titel",
+    "Are you sure you want to delete \"{title}\"?" : "Weet je zeker dat je \"{title}\" wilt verwijderen?",
     "View" : "Bekijken",
     "Import calendars" : "Importeer agenda's",
     "Please select a calendar to import into …" : "Selecteer een agenda om naar te importeren  ...",
@@ -190,15 +191,11 @@ OC.L10N.register(
     "At event start" : "Bij start gebeurtenis",
     "No reminder" : "Geen herinnering",
     "Failed to save default calendar" : "Kon standaardagenda niet opslaan",
-    "CalDAV link copied to clipboard." : "CalDAV link gekopiëerd naar klembord.",
-    "CalDAV link could not be copied to clipboard." : "CalDAV link kon niet worden gekopieerd naar klembord.",
     "General" : "Algemeen",
-    "Copy iOS/macOS CalDAV address" : "Kopieer iOS/macOS CalDAV adres",
     "Appearance" : "Uiterlijk",
     "Editing" : "Bewerken",
-    "Default calendar for incoming invitations" : "Standaardagenda voor inkomende uitnodigingen",
     "Default reminder" : "Standaard herinnering",
-    "Keyboard shortcuts" : "Toetsenbord sneltoetsen",
+    "Files" : "Bestanden",
     "Appointment schedule successfully created" : "Afspraakschema succesvol aangemaakt",
     "Appointment schedule successfully updated" : "Afspraakschema succesvol aangepast",
     "_{duration} minute_::_{duration} minutes_" : ["{duration} minuut","{duration} minuten"],
@@ -215,6 +212,7 @@ OC.L10N.register(
     "Create appointment schedule" : "Maak afspraakschema",
     "Edit appointment schedule" : "Bewerk afspraakschema",
     "Update" : "Bijwerken",
+    "(copy)" : "(kopieer)",
     "Appointment name" : "Afspraak benaming",
     "Location" : "Locatie",
     "Create a Talk room" : "Maak een Talk ruimte",
@@ -325,11 +323,8 @@ OC.L10N.register(
     "Accept" : "Accepteren",
     "Decline" : "Afwijzen",
     "Tentative" : "Voorlopig",
+    "Copied to clipboard" : "Gekopieerd naar het klembord",
     "No attendees yet" : "Nog geen deelnemers",
-    "{invitedCount} invited, {confirmedCount} confirmed" : "{invitedCount} uitgenodigd, {confirmedCount} bevestigd",
-    "Successfully appended link to talk room to location." : "Succesvol de link naar de Talk ruimte aan de locatie toegevoegd.",
-    "Successfully appended link to talk room to description." : "Met succes een link naar de gespreksruimte toegevoegd aan de beschrijving.",
-    "Error creating Talk room" : "Fout tijdens aanmaken gespreksruimte",
     "Attendees" : "Deelnemers",
     "Remove group" : "Groep verwijderen",
     "Remove attendee" : "Verwijder genodigde",
@@ -444,7 +439,6 @@ OC.L10N.register(
     "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "Je ingestelde tijdzone ({timezoneId}) werd niet gevonden. Er wordt teruggevallen op UTC.\nWijzig je tijdzone in instellingen en meld het incident.",
     "Edit event" : "Bewerk gebeurtenis",
     "Event does not exist" : "Activiteit bestaat niet",
-    "Duplicate" : "Duplicaat",
     "Delete this occurrence" : "Verwijder deze afspraak",
     "Delete this and all future" : "Verwijder deze en toekomstige",
     "All day" : "Hele dag",
@@ -550,12 +544,15 @@ OC.L10N.register(
     "This is an event reminder." : "Dit is een herinnering aan een evenement.",
     "Appointment not found" : "Afspraak niet gevonden",
     "User not found" : "Gebruiker niet gevonden",
+    "%1$s - %2$s" : "%1$s - %2$s",
     "Hidden" : "Verborgen",
     "can edit" : "kan wijzigen",
     "Calendar name …" : "Kalendernaam ...",
     "Default attachments location" : "Standaard bijlagenlocatie",
     "Automatic ({detected})" : "Automatisch ({detected})",
     "Shortcut overview" : "Snelkoppeling overzicht",
+    "CalDAV link copied to clipboard." : "CalDAV link gekopiëerd naar klembord.",
+    "CalDAV link could not be copied to clipboard." : "CalDAV link kon niet worden gekopieerd naar klembord.",
     "Enable birthday calendar" : "Verjaardagskalender inschakelen",
     "Show tasks in calendar" : "Toon taken in agenda",
     "Enable simplified editor" : "Eenvoudige editor inschakelen",
@@ -563,9 +560,15 @@ OC.L10N.register(
     "Show weekends" : "Toon weekenden",
     "Show week numbers" : "Tonen weeknummers",
     "Time increments" : "Time-toename",
+    "Default calendar for incoming invitations" : "Standaardagenda voor inkomende uitnodigingen",
     "Copy primary CalDAV address" : "Kopieer primair CalDAV adres",
+    "Copy iOS/macOS CalDAV address" : "Kopieer iOS/macOS CalDAV adres",
     "Personal availability settings" : "Persoonlijke beschikbaarheidsinstellingen",
     "Show keyboard shortcuts" : "Toon sneltoetsen",
+    "{invitedCount} invited, {confirmedCount} confirmed" : "{invitedCount} uitgenodigd, {confirmedCount} bevestigd",
+    "Successfully appended link to talk room to location." : "Succesvol de link naar de Talk ruimte aan de locatie toegevoegd.",
+    "Successfully appended link to talk room to description." : "Met succes een link naar de gespreksruimte toegevoegd aan de beschrijving.",
+    "Error creating Talk room" : "Fout tijdens aanmaken gespreksruimte",
     "The visibility of this event in shared calendars." : "De zichtbaarheid van deze afspraak in gedeelde agenda's."
 },
 "nplurals=2; plural=(n != 1);");
