@@ -412,6 +412,7 @@ OC.L10N.register(
     "Personal" : "Osebno",
     "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "Samodejno zaznavanje časovnega pasu določa časovni pas kot UTC.\nTo je najverjetneje prilagojeno na varnostne nastavitve spletnega brskalnika.\nČasovni pas lahko določite tudi ročno med nastavitvami koledarja.",
     "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "Nastavljenega časovnega pasu ({timezoneId}) ni mogoče najti. Povrnjena bo nastavitev na UTC.\nČasovni pas določite ročno med nastavitvami koledarja in pošljite poročilo o napaki.",
+    "Discard changes" : "Opusti spremembe",
     "Edit event" : "Uredi dogodek",
     "Event does not exist" : "Dogodek ne obstaja",
     "Delete this occurrence" : "Izbriši to pojavitev",
@@ -422,6 +423,7 @@ OC.L10N.register(
     "Invite" : "Povabi",
     "Untitled event" : "Neimenovan dogodek",
     "Close" : "Zapri",
+    "This event was cancelled" : "Dogodek je preklican",
     "Selected" : "Izbrano",
     "Title" : "Naslov",
     "30 min" : "30 min",
