@@ -22,7 +22,8 @@ OC.L10N.register(
     "Appointments" : "Möten",
     "Schedule appointment \"%s\"" : "Schemalägg möte ”%s”",
     "Schedule an appointment" : "Schemalägg ett möte",
-    "%1$s - %2$s" : "%1$s - %2$s",
+    "Requestor Comments:" : "Begärarens kommentarer:",
+    "Appointment Description:" : "Mötesbeskrivning:",
     "Prepare for %s" : "Förberedelse inför %s",
     "Follow up for %s" : "Uppföljning av %s",
     "Your appointment \"%s\" with %s needs confirmation" : "Ditt möte \"%s\" med %s behöver bekräftas",
@@ -48,10 +49,14 @@ OC.L10N.register(
     "Dear %s, a proposed meeting has been updated" : "Hej %s, ett föreslaget möte har uppdaterats",
     "Dear %s, a proposed meeting has been cancelled" : "Hej %s, ett föreslaget möte har avbokats",
     "Location:" : "Ort:",
+    "%1$s minutes" : "%1$s minuter",
     "Duration:" : "Varaktighet:",
     "%1$s from %2$s to %3$s" : "%1$s från %2$s till %3$s",
     "Dates:" : "Datum:",
     "Respond" : "Svara",
+    "[Proposed] %1$s" : "[Föreslagen] %1$s",
+    "Calendar App" : "Kalender App",
+    "Calendars App settings including proposals and appointments schedule configurations." : "Inställningar för Kalender-appen, inklusive förslag och konfiguration av möten.",
     "A Calendar app for Nextcloud" : "En kalender-app för Nextcloud",
     "Previous day" : "Föregående dag",
     "Previous week" : "Föregående vecka",
@@ -73,6 +78,7 @@ OC.L10N.register(
     "Appointment link could not be copied to clipboard" : "Möteslänk kunde ej kopieras till urklipp",
     "Preview" : "Förhandsvisa",
     "Copy link" : "Kopiera länk",
+    "Duplicate" : "Duplicera",
     "Edit" : "Redigera",
     "Delete" : "Ta bort",
     "Appointment schedules" : "Mötesscheman",
@@ -243,6 +249,7 @@ OC.L10N.register(
     "Create appointment schedule" : "Skapa mötesschema",
     "Edit appointment schedule" : "Redigera mötesschema",
     "Update" : "Uppdatera",
+    "(copy)" : "(kopia)",
     "Appointment name" : "Namn på möte",
     "Location" : "Plats",
     "Create a Talk room" : "Skapa ett rum i Talk",
@@ -289,11 +296,13 @@ OC.L10N.register(
     "Talk conversation for event" : "Talk-konversation för händelse",
     "Error creating Talk conversation" : "Kunde inte skapa Talk-konversation",
     "Select a Talk Room" : "Välj ett rum i Talk",
-    "Add Talk conversation" : "Lägg till Talk-konversation",
     "Fetching Talk rooms…" : "Hämtar Talk-rum...",
     "No Talk room available" : "Inget Talk-rum tillgängligt",
-    "Create public conversation" : "Skapa offentlig konversation",
+    "Select existing conversation" : "Välj befintlig konversation",
     "Select conversation" : "Välj konversation",
+    "Or create a new conversation" : "Eller skapa en ny konversation",
+    "Create public conversation" : "Skapa offentlig konversation",
+    "Create private conversation" : "Skapa privat konversation",
     "on" : "den",
     "at" : "kl",
     "before at" : "innan",
@@ -375,6 +384,9 @@ OC.L10N.register(
     "Accept" : "Acceptera",
     "Decline" : "Avböj",
     "Tentative" : "Preliminärt",
+    "Copied to clipboard" : "Kopierat till urklipp",
+    "Failed to copy" : "Det gick inte att kopiera",
+    "Copy name and email address" : "Kopiera namn och e-postadress",
     "No attendees yet" : "Inga deltagare än",
     "{confirmedCount} confirmed, {waitingCount} awaiting response" : "{confirmedCount} bekräftade, {waitingCount} väntar på svar",
     "Please add at least one attendee to use the \"Find a time\" feature." : "Lägg till minst en deltagare för att använda funktionen “Hitta en tid”.",
@@ -507,14 +519,14 @@ OC.L10N.register(
     "Show unscheduled tasks" : "Visa ej schemalagda uppgifter",
     "Unscheduled tasks" : "Ej schemalagda uppgifter",
     "Availability of {displayName}" : "Tillgänglighet för {displayName}",
-    "Discard event" : "Avbryt händelse",
+    "Discard changes" : "Släng ändringar",
     "Edit event" : "Redigera händelse",
     "Event does not exist" : "Händelsen existerar inte",
-    "Duplicate" : "Duplicera",
     "Delete this occurrence" : "Ta bort denna förekomst",
     "Delete this and all future" : "Ta bort denna och alla kommande",
     "All day" : "Heldag",
     "Modifications wont get propagated to the organizer and other attendees" : "Ändringar kommer inte att skickas till organisatören eller andra deltagare",
+    "Add Talk conversation" : "Lägg till Talk-konversation",
     "Managing shared access" : "Hantering av delad åtkomst",
     "Deny access" : "Neka åtkomst",
     "Invite" : "Bjud in",
@@ -525,6 +537,7 @@ OC.L10N.register(
     "Untitled event" : "Namnlös händelse",
     "Close" : "Stäng",
     "Modifications will not get propagated to the organizer and other attendees" : "Ändringar kommer inte att skickas till organisatören eller andra deltagare",
+    "This event was cancelled" : "Detta evenemang har blivit inställt",
     "Meeting proposals overview" : "Översikt över mötesförslag",
     "Edit meeting proposal" : "Redigera mötesförslag",
     "Create meeting proposal" : "Skapa mötesförslag",
@@ -670,6 +683,7 @@ OC.L10N.register(
     "Error while parsing a PROPFIND error" : "Fel vid analys av ett PROPFIND-fel",
     "Appointment not found" : "Mötet hittades inte",
     "User not found" : "Användaren hittades inte",
+    "%1$s - %2$s" : "%1$s - %2$s",
     "Hidden" : "Gömd",
     "can edit" : "kan redigera",
     "Calendar name …" : "Kalendernamn ...",
